@@ -1,5 +1,5 @@
 import gtk, pango, gobject
-import deskbar.interfaces.Action
+import logging
 
 class CuemiacHistoryView (gtk.ComboBox):
 
@@ -9,7 +9,8 @@ class CuemiacHistoryView (gtk.ComboBox):
     
     def __init__ (self, historystore):
         gtk.ComboBox.__init__ (self, historystore)
-                
+        historystore.connect("cleared", self.__select_default_item)
+        
         icon = gtk.CellRendererPixbuf ()
         icon.set_property("xpad", 4)
         icon.set_property("xalign", 0.1)
@@ -40,17 +41,31 @@ class CuemiacHistoryView (gtk.ComboBox):
         timestamp, text, action = model[iter]
         if action == None:
             return
-        cell.set_property ("markup", action.get_verb () % action.get_escaped_name(text))
+        
+        text = action.get_verb () % action.get_escaped_name(text)
+        # We only want to display the first line of text
+        # E.g. some beagle-live actions display a snippet in the second line 
+        text = text.split("\n")[0]
+        cell.set_property ("markup", text)
 
     def __on_activated (self):
         iter = self.get_active_iter()
         if iter != None:
             timestamp, text, action = self.get_model()[iter]
+            if not action.is_valid():
+                logging.warning("Action is not valid anymore. Removing it from history.")
+                self.get_model().remove(iter)
+                self.__select_default_item()
+                return False
             self.emit ("match-selected", text, action)
-            self.handler_block(self.__changed_id)
-            self.set_active ( 0 )
-            self.handler_unblock(self.__changed_id)
+            self.__select_default_item()
+            
         return False
 
+    def __select_default_item(self, model=None):
+        self.handler_block(self.__changed_id)
+        self.set_active ( 0 )
+        self.handler_unblock(self.__changed_id)
+
 if gtk.pygtk_version < (2,8,0):    
     gobject.type_register (CuemiacHistoryView)
