@@ -1,10 +1,9 @@
 import gtk
 import gtk.gdk
 import gtk.glade
-import gobject
 import traceback
 from gettext import gettext as _
-from os.path import join, isdir
+from os.path import join
 import deskbar
 from deskbar.core.updater.NewStuffUpdater import NewStuffUpdater
 from deskbar.core.ModuleList import WebModuleList
@@ -23,6 +22,7 @@ class InfoBox(gtk.HBox):
         self.info_image.set_padding(3, 0)
         self.pack_start(self.info_image, expand=False, fill=False)
         self.label = gtk.Label()
+        self.label.set_line_wrap(True)
         self.label.set_alignment(0.0, 0.5)
         self.label.set_justify(gtk.JUSTIFY_LEFT)
         self.label.set_markup(text)
@@ -41,13 +41,6 @@ class DeskbarPreferences:
         
         # Since newstuff is optional we have to check if self.newstuff is None each time we use it
         self.newstuff = None
-            
-        # Retreive current values
-        # TODO: width and expand still missing
-        #self.width = deskbar.GCONF_CLIENT.get_int(applet.prefs.GCONF_WIDTH)
-        #self.expand = deskbar.GCONF_CLIENT.get_bool(applet.prefs.GCONF_EXPAND)
-        self.width = 20
-        self.expand = False
         
         self.keybinding = self._model.get_keybinding()
         
@@ -68,9 +61,6 @@ class DeskbarPreferences:
         self.sync_ui()
 
     def __setup_active_modules_tab(self):
-        # List of modules
-        self.module_list.connect ("rows-reordered", lambda a,b,c,d: self.update_gconf())
-        
         container = self.glade.get_widget("handlers")
         self.moduleview = ModuleListView(self.module_list)
         self.moduleview.connect ("row-toggled", self.on_module_toggled)
@@ -103,15 +93,6 @@ class DeskbarPreferences:
         self.button_bottom.connect("clicked", self.on_button_bottom_clicked)
 
     def __setup_general_tab(self):
-    	self.hide_after_action = self.glade.get_widget("hide_after_action")
-    	self.hide_after_action.connect("toggled", self.on_hide_after_action_toggled)
-    	
-    	self.typingdelay = self.glade.get_widget("typingdelay")
-    	self.typingdelay.connect("value-changed", self.on_typingdelay_value_changed)
-    	
-    	self.max_history_items = self.glade.get_widget("max_history_items")
-    	self.max_history_items.connect("value-changed", self.on_max_history_items_changed)
-    	
         self.keyboard_shortcut_entry = AccelEntry()
         self.keyboard_shortcut_entry.connect('accel-edited', self.on_keyboard_shortcut_entry_changed)
         self.glade.get_widget("keybinding_entry_container").pack_start(self.keyboard_shortcut_entry.get_widget(), False)
@@ -205,18 +186,13 @@ class DeskbarPreferences:
         self.moduleview.grab_focus()
         self.dialog.connect("response", self.on_dialog_response)
     
-    def on_dialog_response(self, dialog, response):    
+    def on_dialog_response(self, dialog, response):
+        self.update_gconf()    
         self.dialog.destroy()
         if self.newstuff != None:
             self.newstuff.close()
         
     def sync_ui(self):
-    	self.hide_after_action.set_active( self._model.get_hide_after_action() )
-    	
-    	self.typingdelay.set_value( self._model.get_type_delay() )
-    	
-    	self.max_history_items.set_value( self._model.get_max_history_items() )
-    	
         if self.keybinding != None:
             self.keyboard_shortcut_entry.set_accelerator_name(self.keybinding)
         else:
@@ -225,13 +201,13 @@ class DeskbarPreferences:
         self.use_selection_box.set_active(self.use_selection)
    
     def on_hide_after_action_toggled(self, toggle):
-    	self._model.set_hide_after_action(toggle.get_active())
-    	
+        self._model.set_hide_after_action(toggle.get_active())
+        
     def on_typingdelay_value_changed(self, spinbutton):
-    	self._model.set_type_delay(spinbutton.get_value())
-    	
+        self._model.set_type_delay(spinbutton.get_value())
+        
     def on_max_history_items_changed(self, spinbutton):
-    	self._model.set_max_history_items(spinbutton.get_value())
+        self._model.set_max_history_items(spinbutton.get_value())
             
     def on_keyboard_shortcut_entry_changed(self, entry, accel_name, keyval, mods, keycode):        
         if accel_name != "":
@@ -250,7 +226,6 @@ class DeskbarPreferences:
         
         if module_context != None:
             self.check_requirements(module_context)
-            gobject.timeout_add(1000, self.poll_requirements, module_context)
             
         # Check if we can update
         if self.newstuff != None:
@@ -283,18 +258,10 @@ class DeskbarPreferences:
         
         if (len(self.disabledhandlers_box.get_children()) > 1):
             self.disabledhandlers_box.remove( self.disabledhandlers_box.get_children()[1] )
-        self.disabledhandlers_box.pack_end(InfoBox(module.INSTRUCTIONS, gtk.STOCK_DIALOG_ERROR), False, False, 0)
+        if hasattr(module, "INSTRUCTIONS") and module.INSTRUCTIONS != None and module.INSTRUCTIONS != "":
+            self.disabledhandlers_box.pack_end(InfoBox(module.INSTRUCTIONS, gtk.STOCK_DIALOG_ERROR), False, False, 0)
         self.disabledhandlers_box.show_all()
-     
-    def poll_requirements(self, module_context):
-        try:
-            if module_context != self.moduleview.get_selected_module():
-                return False
-        except AttributeError:
-            return False
-        self.check_requirements(module_context)
-        return True
-    
+  
     def check_requirements(self, module):
         if module is None:
             return
@@ -316,14 +283,15 @@ class DeskbarPreferences:
         self.old_info_message = message
         
         self.info_area.remove(self.info_area.get_children()[0])
-        if message == None or message == "":
-            self.info_area.add(self.default_info)
-            self.more_button.set_sensitive(False)
-        else:
+        
+        if callable(callback):
             other_info = InfoBox(message, stock_icon)
             self.info_area.add( other_info )
             other_info.show_all()
             self.more_button.set_sensitive(self.more_button_callback != None)
+        else:
+            self.info_area.add(self.default_info)
+            self.more_button.set_sensitive(False)
     
     def on_module_toggled(self, moduleview, module):
         if (module.is_enabled()):
@@ -378,7 +346,7 @@ class DeskbarPreferences:
     def on_install_handler(self, button):
         # Install the selected new handler
         mod_id = self.webmoduleview.get_selected_module_id()
-        if module != None:
+        if mod_id != None:
             if self.newstuff != None:
                 self.newstuff.install_module(mod_id)
             button.set_sensitive(False)
@@ -417,22 +385,30 @@ class DeskbarPreferences:
     def on_button_top_clicked(self, button):
         model, iter = self.moduleview.get_selection().get_selected()
         self.module_list.move_module_to_top(iter)
+        self.moduleview.scroll_to_iter(iter)
         self.set_buttons(self.moduleview.get_selection())
+        self.moduleview.grab_focus()
     
     def on_button_up_clicked(self, button):
         model, iter = self.moduleview.get_selection().get_selected()
         self.module_list.move_module_up(iter)
+        self.moduleview.scroll_to_iter(iter)
         self.set_buttons(self.moduleview.get_selection())
+        self.moduleview.grab_focus()
     
     def on_button_down_clicked(self, button):
         model, iter = self.moduleview.get_selection().get_selected()
         self.module_list.move_module_down(iter)
+        self.moduleview.scroll_to_iter(iter)
         self.set_buttons(self.moduleview.get_selection())
+        self.moduleview.grab_focus()
     
     def on_button_bottom_clicked(self, button):
         model, iter = self.moduleview.get_selection().get_selected()
         self.module_list.move_module_to_bottom(iter)
+        self.moduleview.scroll_to_iter(iter)
         self.set_buttons(self.moduleview.get_selection())
+        self.moduleview.grab_focus()
         
     def update_gconf(self):
          # Update the gconf enabled modules settings
